==> sight_24.1.0.orig.tar.gz: sight-24.1.0/libs/__/app/test/ut/test_services.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2023 IRCAD France
 * Copyright (C) 2012-2019 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <core/base.hpp>

#include <data/image.hpp>

#include <service/macros.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::app::ut
{

/**
 * @brief   Service type for test.
 */
class test_config_service : public service::base
{
public:

    SIGHT_DECLARE_SERVICE(test_config_service, service::base);

    ~test_config_service() noexcept override =
        default;

    /// return true if the service is updated with updating() method
    bool get_is_updated() const
    {
        return m_is_updated;
    }

protected:

    //------------------------------------------------------------------------------

    void configuring() override
    {
    }

    //------------------------------------------------------------------------------

    void starting() override
    {
    }

    //------------------------------------------------------------------------------

    void stopping() override
    {
    }

    //------------------------------------------------------------------------------

    void updating() override
    {
    }

    //------------------------------------------------------------------------------

    void info(std::ostream& _sstream) override
    {
        _sstream << "TestConfigService";
    }

    bool m_is_updated {false};
};

/**
 * @brief   Test service implementation for image
 */
class test1_image : public test_config_service
{
public:

    SIGHT_DECLARE_SERVICE(test1_image, app::ut::test_config_service);

    ~test1_image() noexcept override =
        default;

    //------------------------------------------------------------------------------

    void configuring() override
    {
    }

    //------------------------------------------------------------------------------

    void starting() override
    {
    }

    //------------------------------------------------------------------------------

    void stopping() override
    {
    }

    //------------------------------------------------------------------------------

    void updating() override
    {
        m_is_updated = true;
    }

    data::ptr<data::image, data::access::in> m_input {this, "data", true, true};
};

} // namespace sight::app::ut

==> sight_25.0.0.orig.tar.gz: sight-25.0.0/libs/__/app/test/ut/test_services.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2024 IRCAD France
 * Copyright (C) 2012-2019 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <core/base.hpp>

#include <data/image.hpp>

#include <service/macros.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::app::ut
{

/**
 * @brief   Service type for test.
 */
class test_config_service : public service::base
{
public:

    SIGHT_DECLARE_SERVICE(test_config_service, service::base);

    ~test_config_service() noexcept override =
        default;

    /// return true if the service is updated with updating() method
    bool is_updated() const
    {
        return m_is_updated;
    }

protected:

    //------------------------------------------------------------------------------

    void configuring() override
    {
    }

    //------------------------------------------------------------------------------

    void starting() override
    {
    }

    //------------------------------------------------------------------------------

    void stopping() override
    {
    }

    //------------------------------------------------------------------------------

    void updating() override
    {
    }

    //------------------------------------------------------------------------------

    void info(std::ostream& _sstream) override
    {
        _sstream << "TestConfigService";
    }

    bool m_is_updated {false};
};

/**
 * @brief   Test service implementation for image
 */
class test1_image : public test_config_service
{
public:

    SIGHT_DECLARE_SERVICE(test1_image, app::ut::test_config_service);

    ~test1_image() noexcept override =
        default;

    //------------------------------------------------------------------------------

    void configuring() override
    {
    }

    //------------------------------------------------------------------------------

    void starting() override
    {
    }

    //------------------------------------------------------------------------------

    void stopping() override
    {
    }

    //------------------------------------------------------------------------------

    void updating() override
    {
        m_is_updated = true;
    }

    data::ptr<data::image, data::access::in> m_input {this, "data", true};
};

/**
 * @brief Service for updater tests
 */
class test_order_srv final : public service::base
{
public:

    SIGHT_DECLARE_SERVICE(test_order_srv, service::base);

    static unsigned int s_ORDER;

    //------------------------------------------------------------------------------

    ~test_order_srv() noexcept final = default;

    //------------------------------------------------------------------------------

    void configuring(const config_t&) final
    {
    }

    //------------------------------------------------------------------------------

    void starting() final
    {
    }

    //------------------------------------------------------------------------------

    void stopping() final
    {
    }

    //------------------------------------------------------------------------------

    void updating() final
    {
        m_update_order = s_ORDER++;
    }

    //------------------------------------------------------------------------------

    unsigned int update_order() const
    {
        return m_update_order;
    }

protected:

    unsigned int m_update_order {0};
};

class test_reset_order_srv final : public service::base
{
public:

    SIGHT_DECLARE_SERVICE(test_reset_order_srv, service::base);

    //------------------------------------------------------------------------------

    ~test_reset_order_srv() noexcept final = default;

    //------------------------------------------------------------------------------

    void configuring(const config_t&) final
    {
    }

    //------------------------------------------------------------------------------

    void starting() final
    {
    }

    //------------------------------------------------------------------------------

    void stopping() final
    {
    }

    //------------------------------------------------------------------------------

    void updating() final
    {
        test_order_srv::s_ORDER = 1;
    }
};

} // namespace sight::app::ut
